OC.L10N.register(
    "files",
    {
    "Added to favorites" : "已添加到收藏夹",
    "Removed from favorites" : "从收藏夹移除",
    "You added {file} to your favorites" : "您已经添加 {file} 到您的收藏夹",
    "You removed {file} from your favorites" : "您已从收藏夹中移除 {file}",
    "Favorites" : "收藏",
    "File changes" : "文件变动",
    "Created by {user}" : "由 {user} 创建",
    "Changed by {user}" : "由 {user} 更改",
    "Deleted by {user}" : "由 {user} 删除",
    "Restored by {user}" : "由 {user} 恢复",
    "Renamed by {user}" : "由 {user} 重命名",
    "Moved by {user}" : "由 {user} 移动",
    "\"remote account\"" : "远程账号",
    "You created {file}" : "您创建了 {file}",
    "You created an encrypted file in {file}" : "您在 {file} 创建了一个加密文件",
    "{user} created {file}" : "{user} 创建了 {file}",
    "{user} created an encrypted file in {file}" : "{user} 在 {file} 中创建一个加密文件",
    "{file} was created in a public folder" : "{file} 被创建在公共文件夹",
    "You changed {file}" : "您更改了 {file}",
    "You changed an encrypted file in {file}" : "您在 {file} 更改了加密文件",
    "{user} changed {file}" : "{user} 更改了 {file}",
    "{user} changed an encrypted file in {file}" : "{user} 在 {file} 更改了加密文件",
    "You deleted {file}" : "您删除了{file}",
    "You deleted an encrypted file in {file}" : "您在 {file} 删除了加密文件",
    "{user} deleted {file}" : "{user} 删除了 {file}",
    "{user} deleted an encrypted file in {file}" : "{user} 在 {file} 删除了加密文件",
    "You restored {file}" : "您恢复了{file}",
    "{user} restored {file}" : "{user} 恢复了 {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "您将 {oldfile}（隐藏）重命名为 {newfile}（隐藏）",
    "You renamed {oldfile} (hidden) to {newfile}" : "您将 {oldfile}（隐藏）重命名为 {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "您将 {oldfile} 重命名为了 {newfile}（隐藏）",
    "You renamed {oldfile} to {newfile}" : "您将 {oldfile} 改名为 {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} 将 {oldfile}（隐藏）重命名为 {newfile}（隐藏）",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} 将 {oldfile}（隐藏）重命名为 {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} 将 {oldfile} 重命名为 {newfile}（隐藏）",
    "{user} renamed {oldfile} to {newfile}" : "{user} 将 {oldfile} 改名为 {newfile}",
    "You moved {oldfile} to {newfile}" : "您将 {oldfile} 移动到了 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 将 {oldfile} 移动到了 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "文件已经添加或删除到您的<strong>收藏夹</strong> 中",
    "Files" : "文件",
    "A file or folder has been <strong>changed</strong>" : "文件或文件夹已经被<strong>修改</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "一个收藏的文件或文件夹已经被<strong>修改</strong>",
    "Failed to authorize" : "授权失败",
    "Invalid folder path" : "无效文件夹路径",
    "Folder not found" : "未找到文件夹",
    "The file cannot be found" : "找不到文件",
    "The destination path does not exist: %1$s" : "目标路径不存在：%1$s",
    "You do not have permission to create a file at the specified location" : "您没有在指定位置创建文件的权限",
    "The file could not be converted." : "无法转换文件。",
    "Could not get relative path to converted file" : "无法获取转换文件的相对路径",
    "Favorite files" : "收藏的文件",
    "No favorites" : "无收藏",
    "More favorites" : "更多收藏",
    "Upload (max. %s)" : "上传 （最大 %s）",
    "Accept" : "接受",
    "Reject" : "拒绝",
    "Incoming ownership transfer from {user}" : "来自 {user} 的所有权转移",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您要接受 {path} 吗？\n\n注意：接受后转移过程可能长达1小时。",
    "Ownership transfer denied" : "所有权转移被拒绝",
    "Your ownership transfer of {path} was denied by {user}." : "你路径 {path} 下的文件所属权转移被 {user} 拒绝。",
    "Ownership transfer failed" : "所有权转移失败",
    "Your ownership transfer of {path} to {user} failed." : "您 {path} 的所有权向 {user} 转移失败。",
    "The ownership transfer of {path} from {user} failed." : "来自 {user} 的 {path} 的所有权转移失败。",
    "Ownership transfer done" : "所有权转移完成",
    "Your ownership transfer of {path} to {user} has completed." : "您的 {path} 向 {user} 的所有权转移已完成。",
    "The ownership transfer of {path} from {user} has completed." : "来自 {user} 的 {path} 的所有权转移已完成。",
    "in %s" : "在 %s",
    "Transferred from %1$s on %2$s" : "从 %1$s 转移至 %2$s",
    "Files compatibility" : "文件兼容性",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允许限制文件名称以确保文件可以与所有客户端同步。默认状态下，所有POSIX（例如 Linux 或 macOS）系统有效的文件名都是被允许的。",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "启用与 Windows 兼容的文件名后，无法再修改现有文件，但可以由其所有者重命名为有效的新名称。",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "启用此设置后，也可以自动迁移文件，请参阅有关 occ 命令的文档。",
    "Enforce Windows compatibility" : "强制 Windows 兼容性",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "这将阻止在 Windows 系统中无效的文件名称，比如使用保留字符。但这不会强制大小写敏感性兼容。",
    "File Management" : "文件管理",
    "Home" : "首页",
    "Target folder does not exist any more" : "目标文件夹已不存在",
    "Reload current directory" : "重新载入当前目录",
    "Go to the \"{dir}\" directory" : "前往“{dir}”目录",
    "Current directory path" : "当前文件目录",
    "Your have used your space quota and cannot upload files anymore" : "你已用完你的空间配额，无法再上传更多文件",
    "You do not have permission to upload or create files here." : "您没有在此处上传或创建文件的权限。",
    "Drag and drop files here to upload" : "将文件拖放至此处以上传",
    "Favorite" : "收藏",
    "Back" : "返回",
    "Toggle selection for file \"{displayName}\"" : "切换文件 “{displayName}” 的选择",
    "Toggle selection for folder \"{displayName}\"" : "切换文件夹 “{displayName}” 的选择",
    "File is loading" : "正在加载文件",
    "Folder is loading" : "正在加载文件夹",
    "Filename" : "文件名",
    "Folder name" : "文件夹名称",
    "This node is unavailable" : "此节点不可用",
    "Another entry with the same name already exists." : "另一相同名称的条目已存在。",
    "Invalid filename." : "无效文件名称。",
    "Renamed \"{oldName}\" to \"{newName}\"" : "已将“{oldName}”重命名为“{newName}”",
    "Rename file" : "重命名文件",
    "Folder" : "文件夹",
    "Pending" : "等待",
    "Unknown date" : "未知日期",
    "Clear filter" : "清除筛选",
    "Modified" : "修改日期",
    "Type" : "类型",
    "Active filters" : "已开启的过滤器",
    "Remove filter" : "移除过滤条件",
    "Total rows summary" : "总行摘要",
    "Toggle selection for all files and folders" : "切换所有文件和文件夹的选择",
    "Name" : "名称",
    "Size" : "大小",
    "\"{displayName}\" failed on some elements" : "“{displayName}”在某些元素上失败",
    "\"{displayName}\" batch action executed successfully" : "批量操作“{displayName}”运行成功",
    "\"{displayName}\" action failed" : "“{displayName}”操作执行失败",
    "Actions" : "操作",
    "(selected)" : "（选中）",
    "List of files and folders." : "文件与文件夹列表。",
    "You have used your space quota and cannot upload files anymore." : "您的剩余空间配额不足以继续上传文件。",
    "Column headers with buttons are sortable." : "带有按钮的列标题可进行排序。",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出于性能考虑，此列表未完全呈现。文件将在您浏览列表时呈现。",
    "File not found" : "文件未找到",
    "{count} selected" : "已选中 {count}",
    "{usedQuotaByte} used" : "{usedQuotaByte} 已使用",
    "{used} of {quota} used" : "已使用 {used} / {quota}",
    "{relative}% used" : "{relative}% 已使用",
    "Could not refresh storage stats" : "无法刷新存储统计数据",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
    "Storage information" : "存储信息",
    "Storage quota" : "存储配额",
    "New folder" : "新建文件夹",
    "Create new folder" : "创建新文件夹",
    "This name is already in use." : "此名称已被使用。",
    "Create" : "创建",
    "Fill template fields" : "填写模板字段",
    "Submitting fields …" : "正在提交字段…",
    "Submit" : "使用",
    "Choose a file or folder to transfer" : "选择要转移的文件或文件夹",
    "Transfer" : "转移",
    "Transfer {path} to {userid}" : "将 {path} 转移给 {userid}",
    "Invalid path selected" : "选择的路径无效",
    "Unknown error" : "未知错误",
    "Ownership transfer request sent" : "所有权转移请求已发送",
    "Cannot transfer ownership of a file or folder you do not own" : "无法转让您未拥有的文件或文件夹的所有权",
    "Transfer ownership of a file or folder" : "转移文件或文件夹的所有权",
    "Choose file or folder to transfer" : "选择要转移的文件或文件夹",
    "Change" : "修改",
    "New owner" : "新的所有者",
    "Keep {old}" : "保留 {old}",
    "Keep without extension" : "保留但不包含扩展名",
    "Use {new}" : "使用 {new}",
    "Remove extension" : "移除扩展名",
    "Change file extension" : "更改文件扩展名",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "将文件扩展名从 \"{old}\" 更改为 \"{new}\" 可能会导致文件无法读取。",
    "Removing the file extension \"{old}\" may render the file unreadable." : "删除文件扩展名 \"{old}\" 可能会导致文件无法读取。",
    "Adding the file extension \"{new}\" may render the file unreadable." : "添加文件扩展名 \"{new}\" 可能会导致文件无法读取。",
    "Do not show this dialog again." : "不再显示此对话框。",
    "Select file or folder to link to" : "选择需要链接的文件或文件夹",
    "Choose {file}" : "选择 {file}",
    "Share" : "共享",
    "Shared by link" : "通过链接共享",
    "Shared" : "已共享",
    "Switch to list view" : "切换为列表视图",
    "Switch to grid view" : "切换到网格视图",
    "The file could not be found" : "找不到文件",
    "Upload was cancelled by user" : "用户已取消上传",
    "Not enough free space" : "可用空间不足",
    "Operation is blocked by access control" : "访问控制阻止此操作",
    "Error during upload: {message}" : "上传时发生错误: {message}",
    "Error during upload, status code {status}" : "上传时发生错误，状态码 {status}",
    "Unknown error during upload" : "上传时发生未知错误",
    "\"{displayName}\" action executed successfully" : "“{displayName}”操作执行成功",
    "Loading current folder" : "正在载入当前文件夹",
    "Retry" : "重试",
    "No files in here" : "这里没有文件",
    "Upload some content or sync with your devices!" : "上传一些内容或与您的设备同步！",
    "Go back" : "返回",
    "Filter file names …" : "筛选文件名…",
    "Views" : "视图",
    "Files settings" : "文件设置",
    "Your files" : "你的文件",
    "Open in files" : "在文件中打开",
    "File cannot be accessed" : "文件无法访问",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到该文件，或是您没有查看该文件的权限。请要求发送者分享它。",
    "Clipboard is not available" : "剪贴板不可用",
    "WebDAV URL copied to clipboard" : "WebDAV 链接已复制到剪贴板",
    "Sort favorites first" : "收藏排序优先",
    "Sort folders before files" : "将文件夹排在文件前面",
    "Show hidden files" : "显示隐藏文件",
    "Crop image previews" : "裁剪图片预览",
    "Enable the grid view" : "启用网格视图",
    "Enable folder tree" : "启用文件夹树",
    "Additional settings" : "其他设置",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "复制到剪贴板",
    "Use this address to access your Files via WebDAV" : "使用此地址通过 WebDAV 访问您的文件",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果启用两步验证，您必须点击此处来创建和使用一个新的应用程序密码。",
    "Warnings" : "警告",
    "Prevent warning dialogs from open or reenable them." : "防止打开或重新启用警告对话框。",
    "Show a warning dialog when changing a file extension." : "更改文件扩展名时显示警告对话框。",
    "Keyboard shortcuts" : "键盘快捷键",
    "Speed up your Files experience with these quick shortcuts." : "这些快捷键可以加快你的“文件”体验。",
    "Open the actions menu for a file" : "打开文件的操作菜单",
    "Rename a file" : "重命名文件",
    "Delete a file" : "删除文件",
    "Favorite or remove a file from favorites" : "把文件添加或移除出收藏夹",
    "Manage tags for a file" : "管理文件的标签",
    "Selection" : "选择",
    "Select all files" : "选择所有文件",
    "Deselect all files" : "取消选择所有文件",
    "Select or deselect a file" : "选择或取消选择文件",
    "Select a range of files" : "选择一系列文件",
    "Navigation" : "导航",
    "Navigate to the parent folder" : "前往上一级文件夹",
    "Navigate to the file above" : "跳转至以上文件",
    "Navigate to the file below" : "跳转至以下文件",
    "Navigate to the file on the left (in grid mode)" : "跳转至左侧文件（在网格模式下）",
    "Navigate to the file on the right (in grid mode)" : "跳转至右侧文件（在网格模式下）",
    "View" : "查看",
    "Toggle the grid view" : "切换网格视图",
    "Open the sidebar for a file" : "在侧边栏打开文件",
    "Show those shortcuts" : "显示快捷键",
    "You" : "您",
    "Shared multiple times with different people" : "与不同的用户多次分享",
    "Error while loading the file data" : "加载文件数据时出错",
    "Owner" : "拥有者",
    "Remove from favorites" : "从收藏中移除",
    "Add to favorites" : "添加到收藏夹",
    "Tags" : "标签",
    "Blank" : "空白",
    "Unable to create new file from template" : "无法从模板创建新文件",
    "Pick a template for {name}" : "给 {name} 挑选一个模板",
    "Create a new file with the selected template" : "用所选模板创建一个新文件",
    "Creating file" : "正在创建文件",
    "Save as {displayName}" : "保存为 {displayName}",
    "Save as …" : "保存为…",
    "Converting files …" : "正在转换文件…",
    "Failed to convert files: {message}" : "无法转换文件：{message}",
    "All files failed to be converted" : "无法转换全部文件",
    "One file could not be converted: {message}" : "有一个文件无法转换：{message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["无法转换 %n 个文件"],
    "_One file successfully converted_::_%n files successfully converted_" : ["已成功转换 %n 个文件"],
    "Files successfully converted" : "文件已成功转换",
    "Failed to convert files" : "无法转换文件",
    "Converting file …" : "正在转换文件…",
    "File successfully converted" : "文件已成功转换",
    "Failed to convert file: {message}" : "无法转换文件：{message}",
    "Failed to convert file" : "无法转换文件",
    "Deletion cancelled" : "已取消删除",
    "Leave this share" : "离开此共享",
    "Leave these shares" : "离开此分享",
    "Disconnect storage" : "断开与存储空间的连接",
    "Disconnect storages" : "断开与存储空间的连接",
    "Delete permanently" : "彻底删除",
    "Delete and unshare" : "删除并取消分享",
    "Delete file" : "删除文件",
    "Delete files" : "删除文件",
    "Delete folder" : "删除文件夹",
    "Delete folders" : "删除文件夹",
    "Delete" : "删除",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您正要永久删除 {count} 个项目"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您正要删除 {count} 个项目"],
    "Confirm deletion" : "确认删除",
    "Cancel" : "取消",
    "Moving \"{source}\" to \"{destination}\" …" : "正在移动 “{source}” 至 “{destination}” ...",
    "Copying \"{source}\" to \"{destination}\" …" : "正在复制 “{source}” 至 “{destination}” ...",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "你无法将文件/文件夹移动至其自身或子文件夹中",
    "(copy)" : "（复制）",
    "(copy %n)" : "(复制 %n)",
    "Move cancelled" : "已取消移动",
    "A file or folder with that name already exists in this folder" : "相同的文件/文件夹已存在于该文件夹中",
    "The files are locked" : "文件已锁定",
    "The file does not exist anymore" : "文件不存在",
    "Choose destination" : "选择目标路径",
    "Copy to {target}" : "复制到 {target}",
    "Copy" : "复制",
    "Move to {target}" : "移动到 {target}",
    "Move" : "移动",
    "Move or copy operation failed" : "移动或复制失败",
    "Move or copy" : "移动或复制",
    "Cancelled move or copy of \"{filename}\"." : "取消移动或复制“{filename}”.",
    "Cancelled move or copy operation" : "已取消移动或复制操作",
    "Open folder {displayName}" : "打开文件夹{displayName}",
    "Open in Files" : "在文件中打开",
    "Open file locally" : "在本地打开文件",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "该文件现在应该在你的设备上打开。如果没有，请检查你是否安装了桌面应用程序。",
    "Retry and close" : "重试并关闭",
    "Open online" : "在线打开",
    "Failed to redirect to client" : "重定向到客户端失败",
    "Open locally" : "本地打开",
    "Rename" : "重命名",
    "Open details" : "打开详情",
    "View in folder" : "在文件夹中查看",
    "Today" : "今日",
    "Last 7 days" : "过去 7 天",
    "Last 30 days" : "过去 30 天",
    "This year ({year})" : "今年（{year}）",
    "Last year ({year})" : "去年（{year}）",
    "Documents" : "文档",
    "Spreadsheets" : "表格",
    "Presentations" : "幻灯片",
    "PDFs" : "PDF",
    "Folders" : "文件夹",
    "Audio" : "音频",
    "Photos and images" : "照片和图像",
    "Videos" : "视频",
    "New folder creation cancelled" : "取消创建新文件夹",
    "Created new folder \"{name}\"" : "已创建新文件夹“{name}”",
    "Unable to initialize the templates directory" : "无法初始化模板目录",
    "Create templates folder" : "创建模板文件夹",
    "Templates" : "模板",
    "New template folder" : "新建模板文件夹",
    "In folder" : "文件夹内",
    "Search in folder: {folder}" : "在文件夹内搜索：{folder}",
    "One of the dropped files could not be processed" : "无法处理其中一个已删除的文件",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "你的浏览器不支持文件系统API。目录不会被上传",
    "No files to upload" : "没有需要上传的文件",
    "Unable to create the directory {directory}" : "无法创建目录 {directory}",
    "Some files could not be uploaded" : "部分文件无法上传",
    "Files uploaded successfully" : "上传文件成功",
    "No files to process" : "没有需要处理的文件",
    "Some files could not be copied" : "无法复制某些文件",
    "Some files could not be moved" : "某些文件无法被移动",
    "Files copied successfully" : "复制文件成功",
    "Files moved successfully" : "移动文件成功",
    "Conflicts resolution skipped" : "已跳过冲突解决",
    "Upload cancelled" : "已取消上传",
    "This operation is forbidden" : "该操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
    "Storage is temporarily not available" : "存储空间暂时不可用",
    "Unexpected error: {error}" : "意外错误：{error}",
    "_%n file_::_%n files_" : ["%n 个文件"],
    "_%n folder_::_%n folders_" : ["%n 个文件夹"],
    "_%n hidden_::_%n hidden_" : ["%n 已隐藏"],
    "Filename must not be empty." : "文件名不能为空。",
    "\"{char}\" is not allowed inside a filename." : "文件名中不允许出现 “{char}”",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "“{segment}” 是一个保留名称，不允许用在文件名中。",
    "\"{extension}\" is not an allowed filetype." : "“{extension}” 文件类型不被允许。",
    "Filenames must not end with \"{extension}\"." : "文件名不能以 “{extension}” 结尾。",
    "List of favorite files and folders." : "收藏的文件和文件夹列表。",
    "No favorites yet" : "暂无收藏",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "All files" : "全部文件",
    "List of your files and folders." : "您的文件与文件件列表。",
    "All folders" : "所有文件夹",
    "Personal files" : "个人文件",
    "List of your files and folders that are not shared." : "尚未分享的文件与文件夹",
    "No personal files found" : "找不到个人文件",
    "Files that are not shared will show up here." : "尚未分享的文件会显示在此处",
    "Recent" : "最近",
    "List of recently modified files and folders." : "最近修改的文件与文件夹列表。",
    "No recently modified files" : "近期无修改文件",
    "Files and folders you recently modified will show up here." : "你最近修改的文件与文件夹将会显示在此处。",
    "No entries found in this folder" : "在此文件夹中找不到项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您尝试上传的文件大小超过了服务器的限制。",
    "File could not be found" : "文件未找到",
    "Download" : "下载",
    "Show list view" : "显示列表视图",
    "Show grid view" : "显示网格视图",
    "Close" : "关闭",
    "Could not create folder \"{dir}\"" : "无法创建文件夹“{dir}”",
    "This will stop your current uploads." : "这会终止您当前的上传。",
    "Upload cancelled." : "上传已取消。",
    "Processing files …" : "正在处理文件 ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "无法上传 {filename}，因为它是一个目录或者是大小为 0 的空文件",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空间不足，您上传的文件大小为 {size1} ，但可用空间仅剩 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "目标文件夹“{dir}”不存在",
    "An unknown error has occurred" : "发生了未知错误。",
    "File could not be uploaded" : "文件无法上传",
    "Uploading …" : "正在上传 ...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "上传中 ... （{currentNumber}／{total}）",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "不支持上传此项目",
    "Error when assembling chunks, status code {status}" : "组装块时发生错误，状态码 {status}",
    "Choose target folder" : "选择目标文件夹",
    "Set reminder" : "设置提醒",
    "Edit locally" : "本地编辑",
    "Open" : "打开",
    "Could not load info for file \"{file}\"" : "无法加载文件“{file}”的信息",
    "Details" : "详细信息",
    "Please select tag(s) to add to the selection" : "请选择要添加到所选项目的标签",
    "Apply tag(s) to selection" : "将标签应用到所选项目",
    "Select directory \"{dirName}\"" : "选择目录“{dirName}”",
    "Select file \"{fileName}\"" : "选择文件“{fileName}”",
    "Unable to determine date" : "无法确定日期",
    "Could not move \"{file}\", target exists" : "无法移动“{file}”，目标已存在",
    "Could not move \"{file}\"" : "无法移动“{file}”",
    "copy" : "复制",
    "Could not copy \"{file}\", target exists" : "无法复制“{file}”，目标已存在",
    "Could not copy \"{file}\"" : "无法复制“{file}”",
    "Copied {origin} inside {destination}" : "在 {destination} 内复制 {origin}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "在 {destination} 内复制了 {origin} 和 {nbfiles} 个其他文件",
    "{newName} already exists" : "{newName} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "无法重命名“{fileName}”，此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "文件夹“{dir}”中已经存在“{targetName}”。请尝试其它名称。",
    "Could not rename \"{fileName}\"" : "无法重命名“{fileName}”",
    "Could not create file \"{file}\"" : "无法创建文件“{file}”",
    "Could not create file \"{file}\" because it already exists" : "无法创建文件“{file}”，因为它已经存在",
    "Could not create folder \"{dir}\" because it already exists" : "无法创建文件夹“{dir}”，因为它已经存在",
    "Could not fetch file details \"{file}\"" : "无法获取文件详细信息“{file}”",
    "Error deleting file \"{fileName}\"." : "删除文件“{fileName}”时出错。",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于 {tag}{filter}{endtag} 的搜索结果",
    "Enter more than two characters to search in other folders" : "输入至少三个字符，以搜索其他文件夹",
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
    "You do not have permission to upload or create files here" : "您没有在此上传或创建文件的权限",
    "_Uploading %n file_::_Uploading %n files_" : ["正在上传 %n 个文件"],
    "New" : "新建",
    "New file/folder menu" : "新建文件/文件夹菜单",
    "Select file range" : "选择文件范围",
    "{used}%" : "{used}%",
    "{used} used" : "已使用 {used} 存储空间",
    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "\"/\" is not allowed inside a file name." : "文件名不能包含“/”。",
    "\"{name}\" is not an allowed filetype" : "“{name}”不是允许的文件类型",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的存储已满，无法再更新或同步文件了！",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群组文件夹“{mountPoint}”已满，无法再更新或同步文件！",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部存储器“{mountPoint}”已满，无法再更新或同步文件！",
    "Your storage is full, files cannot be updated or synced anymore!" : "您的的存储已满，无法继续更新或同步文件！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的存储空间几乎已满 ({usedSpacePercent}%)。",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "组文件夹“{mountPoint}”的存储空间几乎已满 ({usedSpacePercent}%)。",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部存储“{mountPoint}”的存储空间几乎已满 ({usedSpacePercent}%)。",
    "Your storage is almost full ({usedSpacePercent}%)." : "您的存储空间几乎已满（{usedSpacePercent}%）",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["匹配“{filter}”"],
    "Direct link was copied (only works for people who have access to this file/folder)" : "已复制直接链接（仅适用于有权访问此文件/文件夹的用户）",
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Copy direct link (only works for people who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
    "Upload file" : "上传文件",
    "Not favorited" : "未收藏",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "You don't have permission to upload or create files here." : "您没有在此处上传或创建文件的权限。",
    "Storage informations" : "存储信息",
    "Choose file" : "选择文件",
    "Go to the previous folder" : "回到前一个文件夹",
    "Open the files app settings" : "打开文件设置",
    "Unable to change the favourite state of the file" : "无法修改文件的收藏状态",
    "Edit file locally" : "本地编辑",
    "Edit online" : "在线编辑",
    "Create new templates folder" : "新建模板文件夹",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 个文件夹"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 个文件"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 个文件夹及 {folderCount} 个文件夹"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 个文件及 1 个文件夹"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} 个文件及 {folderCount} 个文件夹",
    "List of favorites files and folders." : "收藏文件和文件夹列表",
    "Personal Files" : "个人文件",
    "Text file" : "文本文件",
    "New text file.txt" : "新建文本文件.txt",
    "Favored" : "已加入收藏",
    "Favor" : "收藏",
    "Not favored" : "未收藏",
    "Submitting fields…" : "提交字段...",
    "Filter filenames…" : "过滤文件名...",
    "{count} files could not be converted" : "{count} 个文件无法转换",
    "{count} files successfully converted" : "{count} 个文件已成功转换"
},
"nplurals=1; plural=0;");
